function g = grayish(m, maxval)
%GRAYISH   Linear gray-scale color map
%   GRAYISH(M) returns an M-by-3 matrix containing a gray-scale colormap.
%   GRAYISH, by itself, is the same length as the current figure's
%   colormap. If no figure exists, MATLAB uses the length of the
%   default colormap.
%
%   For example, to reset the colormap of the current figure:
%
%             colormap(grayish)
%
%   See also HSV, HOT, COOL, BONE, COPPER, PINK, FLAG, GRAY
%   COLORMAP, RGBPLOT.

%   Adapted from  "GRAY" by RJF Bijster, 2018

if nargin < 1
   f = get(groot,'CurrentFigure');
   if isempty(f)
      m = size(get(groot,'DefaultFigureColormap'),1);
   else
      m = size(f.Colormap,1);
   end
   
end

if nargin < 2
    maxval = 0;
end

g = linspace(0, maxval, max(m-1,1)); g = g';
g = [g g g];