function result = uniformFigureStyle(figureHandle)
% Author: R.J.F. Bijster, 2017 - 2018
% Email: info@roybijster.nl
%
% Sources:
% https://stackoverflow.com/questions/3938348/matlab-how-to-obtain-all-the-axes-handles-in-a-figure-handle

% Get all axes that are in the figure
allAxesInFigure = findall(figureHandle,'type','axes');

% Set the figure rendered to painters (vector graphics)
set(figureHandle, 'Renderer', 'painters');

result = 0;

for k = 1:numel(allAxesInFigure)
    
    ax = allAxesInFigure(k);
    
    % White background color
    ax.Color = [1 1 1];
    % ax.Color = 'none'; % To show no background, good for saving figures; 
    % Axes color
    ax.XColor = [0 0 0];
    ax.YColor = [0 0 0];
    ax.ZColor = [0 0 0]; 
    % Set the box line width to 1 pt
    ax.LineWidth = 1;
    % Show the entire box, not just the axes
    ax.Box = 'on';
    
    
    % Change the grid
    ax.GridColor = [0.15 0.15 0.15];
    ax.MinorGridColor = [0.1 0.1 0.1];
    
    
%     % Font to Myriad Pro instead of Helvetica
%     ax.FontName = 'Myriad Pro';
    % Fontsize to 14
    ax.FontSize = 14;
    
    % Set the linestyleorder
    LineStyleOrder = {'-', '--', ':', '-.'}; 
  
    % Change colormap to gray values
    
    % Find the number of lines
    hline = findobj(ax, 'type', 'line');
    hline = flip(hline);
    % Create a colormap
    cm = grayish(numel(hline)+1, 0.6);
    for m = 1:numel(hline)
        set(hline(m),'Color',cm(m,:))
        set(hline(m),'LineWidth',1)
        set(hline(m),'LineStyle', cycle(LineStyleOrder,m));
    end
    
    % Find all scatter plots
    hscatter = findobj(ax, 'type', 'scatter');
    hscatter = flip(hscatter);
    cm = grayish(numel(hscatter)+1, 0.6);
    for m = 1:numel(hscatter)
        set(hscatter(m),'MarkerEdgeColor',cm(m,:))
        set(hscatter(m),'MarkerFaceColor',cm(m,:))
%         set(hline(m),'LineStyle', cycle(LineStyleOrder,m));
    end
    
    result = result + 1;
end

% 'Remove' all borders from legends
leg = findall(figureHandle, 'Tag', 'legend');
if numel(leg)
    % Set the edge color to white ,without removing its white
    % background
    set(leg, 'EdgeColor', [1 1 1]);
end

% results is number of handles we treated.

end